@@ -506,7 +506,7 @@ def single_grid_search(S, lambda_range, N, method = 'eBIC', gamma = 0.3, latent
             
             # warm start
             kwargs['Omega_0'] = sol['Omega'].copy()
-            kwargs['X_0'] = sol['X'].copy()
+            #kwargs['X_0'] = sol['X'].copy()
             
             AIC[j,m] = aic_single(S, Theta_sol, N)
             for g in gammas:
